# 🙏 Please

<p align="center">
<a href="https://pypi.python.org/pypi/please-av1ppp" target="_blank">
    <img src="https://img.shields.io/pypi/v/please-av1ppp.svg?logo=pypi&logoColor=white" alt="Package version">
</a>
<a href="https://pypi.python.org/pypi/please-av1ppp" target="_blank">
    <img src="https://img.shields.io/badge/python-%3E%3D3.8-green?style=flat&logo=python&logoColor=white" alt="Supported Python version">
</a>
</p>

`Please` is a simple task runner using Python.

### Quick Start

First you need to install the package:

```sh
pip install please-av1ppp
```

Then go to your project directory and run 👇 to initialize `Pleasefile`

```sh
pls -init
```

Now you can run tasks for example with this command:

```sh
pls start -mode=dev
```

---

### TODO

- [ ] Describe instructions for use
- [ ] Add dependency support

&nbsp;

<p align="left">
<a href="ithub.com/av1ppp/please/actions/workflows/python-publish.yml" target="_blank">
    <img src="https://github.com/av1ppp/please/actions/workflows/python-publish.yml/badge.svg" alt="Supported Python version">
</a>
</p>
